@@ -2,6 +2,11 @@ package Nexmo::SMS::MockLWP;
 
 # ABSTRACT: Module for the Nexmo SMS API!
 
+=head1 DESCRIPTION
+
+This module mocks POST requests. It exists only for the unit tests!
+
+=cut
 
 use LWP::UserAgent;
 use HTTP::Response;
@@ -62,50 +67,6 @@ our $VERSION = 0.01;
 
 1;
 
-
-
-
-=pod
-
-=head1 NAME
-
-Nexmo::SMS::MockLWP - Module for the Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 DESCRIPTION
-
-This module mocks POST requests. It exists only for the unit tests!
-
-=head1 VERSION
-
-Version 0.01
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
-
-
 __DATA__
 {
     "http://rest.nexmo.com/sms/json" : {
