@@ -9,7 +9,6 @@ use JSON::PP;
 
 # ABSTRACT: Module that represents a response from Nexmo SMS API!
 
-
 our $VERSION = '0.01';
 
 # create getter/setter
@@ -26,6 +25,56 @@ for my $attr ( @attrs ) {
     };
 }
 
+=head1 SYNOPSIS
+
+This module represents a response from Nexmo.
+
+
+    use Nexmo::SMS::Response;
+
+    my $nexmo = Nexmo::SMS::Response->new(
+        json => '{
+            "message-count":"1",
+            "messages":[
+              {
+              "status":"4",
+              "message-id":"message001",
+              "client-ref":"Test001 - Reference",
+              "remaining-balance":"20.0",
+              "message-price":"0.05",
+              "error-text":""
+              }
+            ]
+        }',
+    );
+    
+    for my $message ( $response ) {
+        print $message->status;
+    }
+
+=head1 METHODS
+
+=head2 new
+
+create a new object
+
+    my $foo = Nexmo::SMS::Response->new(
+        json => '{
+            "message-count":"1",
+            "messages":[
+              {
+              "status":"4",
+              "message-id":"message001",
+              "client-ref":"Test001 - Reference",
+              "remaining-balance":"20.0",
+              "message-price":"0.05",
+              "error-text":""
+              }
+            ]
+        }',
+    );
+
+=cut
 
 sub new {
     my ($class,%param) = @_;
@@ -51,6 +100,14 @@ sub new {
     return $self;
 }
 
+=head2 messages
+
+returns the list of messages included in the response. Each element is an
+object of L<Nexmo::SMS::Response::Message>.
+
+    my @messages = $response->messages;
+
+=cut
 
 sub messages {
     my ($self) = @_;
@@ -70,6 +127,13 @@ sub _add_message {
     }
 }
 
+=head2 errstr
+
+return the "last" error as string.
+
+    print $response->errstr;
+
+=cut
 
 
 sub errstr {
@@ -79,12 +143,22 @@ sub errstr {
     return $self->{__errstr__};
 }
 
+=head2 is_success
+
+returns 1 if all messages have a status = 0, C<undef> otherwise.
+
+=cut
 
 sub is_success {
     my ($self) = @_;
     return !$self->status;
 }
 
+=head2 is_error
+
+Returns 1 if an error occured, 0 otherwise...
+
+=cut
 
 sub is_error {
     my ($self) = @_;
@@ -93,91 +167,6 @@ sub is_error {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Nexmo::SMS::Response - Module that represents a response from Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 SYNOPSIS
-
-This module represents a response from Nexmo.
-
-    use Nexmo::SMS::Response;
-
-    my $nexmo = Nexmo::SMS::Response->new(
-        json => '{
-            "message-count":"1",
-            "messages":[
-              {
-              "status":"4",
-              "message-id":"message001",
-              "client-ref":"Test001 - Reference",
-              "remaining-balance":"20.0",
-              "message-price":"0.05",
-              "error-text":""
-              }
-            ]
-        }',
-    );
-    
-    for my $message ( $response ) {
-        print $message->status;
-    }
-
-=head1 VERSION
-
-Version 0.01
-
-=head1 METHODS
-
-=head2 new
-
-create a new object
-
-    my $foo = Nexmo::SMS::Response->new(
-        json => '{
-            "message-count":"1",
-            "messages":[
-              {
-              "status":"4",
-              "message-id":"message001",
-              "client-ref":"Test001 - Reference",
-              "remaining-balance":"20.0",
-              "message-price":"0.05",
-              "error-text":""
-              }
-            ]
-        }',
-    );
-
-=head2 messages
-
-returns the list of messages included in the response. Each element is an
-object of L<Nexmo::SMS::Response::Message>.
-
-    my @messages = $response->messages;
-
-=head2 errstr
-
-return the "last" error as string.
-
-    print $response->errstr;
-
-=head2 is_success
-
-returns 1 if all messages have a status = 0, C<undef> otherwise.
-
-=head2 is_error
-
-Returns 1 if an error occured, 0 otherwise...
-
 =head1 ATTRIBUTES
 
 These attributes are available for C<Nexmo::SMS::TextMessage> objects:
@@ -195,25 +184,3 @@ These attributes are available for C<Nexmo::SMS::TextMessage> objects:
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
-
